dnl version $Id: ac_dmtoffline.m4 6520 2011-11-01 19:24:44Z john.zweizig@LIGO.ORG $
dnl -*- m4 -*-
dnl----------------------------------------------------------------------
dnl This is a common set of macros to be used in the configuration of
dnl	the low latency data service
dnl----------------------------------------------------------------------

dnl======================================================================
dnl L3D2_CHECK_GANGLIA
dnl   Check if GDS is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_GANGLIA],
[
AC_MSG_CHECKING([whether ganglia plugin enabled])
enable_ganglia=no
gangliacflags=
AC_ARG_ENABLE(ganglia_plugin,
	      AC_HELP_STRING([--enable-ganglia-plugin],
			   [build a ganglia plugin]),
	      enable_ganglia=yes)
AC_MSG_RESULT([$enable_ganglia])
if test $enable_ganglia = "yes"
then
  if test ! -f /usr/include/gm_metric.h
  then
    AC_MSG_ERROR([cannot find ganglia module headers])
  fi
  PKG_CHECK_MODULES(APR, [apr-1], enable_ganglia="yes", enable_ganglia="no")
  if test "$enable_ganglia" = "no"
  then
    AC_MSG_ERROR([cannot find apr-1 package])
  fi
  gangliacflags=$APR_CFLAGS
fi
AM_CONDITIONAL([ganglia_plugin], test x$enable_ganglia != xno )
AC_SUBST([gangliacflags])
])

dnl======================================================================
dnl L3D2_CHECK_GDS
dnl   Check if GDS is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_GDS],
[
AC_ARG_WITH(gds,
	    AC_HELP_STRING([--with-gds@<:@=PATH@:>@],
			   [path to the gds package @<:@/usr@:>@]))
gdsdir=
case "x$with_gds" in
x)
  if test -d "/usr/include/gds"
  then
    CFLAGS="${CFLAGS} -I/usr/include/gds"
    CXXFLAGS="${CXXFLAGS} -I/usr/include/gds"
    gdsdir="/usr"
  fi
  ;;
xno)
  ;;
*)
  if test -d "${with_gds}/include/gds"
  then
    gdsdir=${with_gds}
    CFLAGS="${CFLAGS} -I${gdsdir}/include/gds"
    CXXFLAGS ="${CXXFLAGS} -I${gdsdir}/include/gds"
  fi
  ;;
esac

gdslibdir=
for ldir in lib lib64
do
  if test -f $gdsdir/$ldir/libgdsbase.la
  then
    gdslibdir=$gdsdir/$ldir
  fi
done

AM_CONDITIONAL([have_frame_name], test -f ${gdsdir}/include/gds/frame_name.hh )
AC_SUBST([gdsdir])
AC_SUBST([gdslibdir])

AC_PATH_PROG(DPUSH, DpushM)
AC_PATH_PROG(FRAMELINK, framelink)
AC_PATH_PROG(LSMPXMIT, lsmp_xmit)
AC_PATH_PROG(FRLOG, Frame_Log)
AC_PATH_PROG(SMCRE, smcreate)
AC_PATH_PROG(SMKILL, smkill)
AC_PATH_PROG(SMREP, smrepair)
AC_PATH_PROG(SMSTAT, smstat)
])

dnl======================================================================
dnl L3D2_CHECK_VIGO
dnl   Check if VIRGO is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_VIRGO_APP_FD],
[
AC_MSG_CHECKING([whether Virgo Fd applications requested])
AC_ARG_WITH([virgoapp-fd],
	    AC_HELP_STRING([--with-virgoapp-fd@<:@=PATH@:>@],
			   [path the the virgoApp-Fd package @<:@/usr@:>@. If
			   --without or no is specified, the FdtoDMT and 
			   DMTtoFd executables are not built]))

virgoapps=yes
tmp_libbase=`echo ${libdir} | sed -e 's/^.*lib/lib/g'`
case "x$with_virgoapp_fd" in
x|x/usr|x/usr/|xyes)
  if test -d "/usr/include/virgoApp"
  then
    CFLAGS="${CFLAGS} -I/usr/include/virgoApp"
    CXXFLAGS="${CXXFLAGS} -I/usr/include/virgoApp"
    LDFLAGS="${LDFLAGS} -L/usr/${tmp_libbase}"
  else
    virgoapps=no
  fi
  ;;
xno)
  virgoapps=no
  ;;
*)
  if test -d "${with_virgoapp_fd}/include/virgoApp"
  then
    CFLAGS="${CFLAGS} -I${with_virgoapp_fd}/include/virgoApp"
    CXXFLAGS="${CXXFLAGS} -I${with_virgoapp_fd}/include/virgoApp"
    LDFLAGS="${LDFLAGS} -L${with_virgoapp_fd}/${tmp_libbase}"
  fi
  virgoapps=${with_virgoapp_fd}
  ;;
esac
AC_MSG_RESULT([$virgoapps])
if test x$virgoapps != xno 
then
  AC_PATH_PROG(FDIOSERVER, FdIOServer.exe)
  AC_PATH_PROG(CM,         cm.exe)
fi
AM_CONDITIONAL([have_virgo], test x$virgoapps != xno )
])

dnl======================================================================
dnl L3D2_CHECK_USER
dnl   Check if Username specified is installed
dnl======================================================================

AC_DEFUN([AC_L3D2_CHECK_USER],
[
have_user=no
lluser="lluser"
AC_ARG_WITH(user,
	    AC_HELP_STRING([--with-user@<:@=USER@:>@],
			   [server user name @<:@${lluser}@:>@]),
	    [have_user=yes],
	    [have_user=no]
	    )
if test x$have_user = xyes -a ! -z "$with_user"
then
   lluser=$with_user
fi

AC_SUBST(lluser)
])
